@@ -6,23 +6,27 @@ from adjudicator.Cache import Cache
 from adjudicator.errors import MultipleMatchingRulesError, NoMatchingRulesError, RuleResolveError
 from adjudicator.Executor import Executor
 from adjudicator.Params import Params
-from adjudicator.Rule import Rule, collect_rules, rule
-from adjudicator.RulesEngine import RulesEngine, get
-from adjudicator.RulesGraph import RulesGraph
+from adjudicator.rule import ProductionRule, UnionRule, collect_rules, is_union, rule, union, union_rule
+from adjudicator.RuleEngine import RuleEngine, get
+from adjudicator.RuleGraph import RuleGraph
 
 __all__ = [
     "Cache",
     "collect_rules",
     "Executor",
     "get",
+    "is_union",
     "MultipleMatchingRulesError",
     "NoMatchingRulesError",
     "Params",
+    "ProductionRule",
     "rule",
-    "Rule",
+    "RuleEngine",
+    "RuleGraph",
     "RuleResolveError",
-    "RulesEngine",
-    "RulesGraph",
+    "union_rule",
+    "union",
+    "UnionRule",
 ]
 
-__version__ = "0.2.1"
+__version__ = "0.3.0"
