@@ -4,8 +4,8 @@ from dataclasses import dataclass
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
-    from adjudicator.Rule import Rule
-    from adjudicator.RulesGraph import RulesGraph
+    from adjudicator.rule import ProductionRule
+    from adjudicator.RuleGraph import RuleGraph
     from adjudicator.Signature import Signature
 
 SUBSET_CHAR = "⊆"
@@ -18,13 +18,15 @@ class RuleResolveError(Exception):
 @dataclass
 class NoMatchingRulesError(RuleResolveError):
     sig: Signature
-    graph: RulesGraph
+    graph: RuleGraph
 
     def __str__(self) -> str:
         return f"No rule(s) satisfy the signature {SUBSET_CHAR} {self.sig}" + (
             (
                 f"\nAvailable rules for output type {self.sig.output_type.__name__} are:\n"
-                + "\n".join(f"  {rule.id}: {rule.signature}" for rule in self.graph.rules_for(self.sig.output_type))
+                + "\n".join(
+                    f"  {rule.id}: {rule.signature}" for rule in self.graph.get_production_rules(self.sig.output_type)
+                )
             )
             if self.graph
             else ""
@@ -34,8 +36,8 @@ class NoMatchingRulesError(RuleResolveError):
 @dataclass
 class MultipleMatchingRulesError(RuleResolveError):
     sig: Signature
-    paths: list[list[Rule]]
-    graph: RulesGraph
+    paths: list[list[ProductionRule]]
+    graph: RuleGraph
 
     def __str__(self) -> str:
         return (
